#
# spec file for package guvcview
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Malcolm J Lewis <malcolmlewis@opensuse.org>
# Copyright (c) 2013 Marguerite Su <marguerite@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover0 2_2-2
%define         sover1 2_2-2
%global flavor qt5%{nil}

%define pname guvcview

%if "%{flavor}" == "qt5"
%bcond_without qt5
%define psuffix -qt5
%else
%bcond_with qt5
%endif

Name:           guvcview%{?psuffix}
Version:        2.1.0
Release:        bp160.1.8
# Reference to GPL-2.0 in some files?
Summary:        GTK+ UVC Viewer and Capturer
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Video/Players
URL:            https://guvcview.sourceforge.net/
Source0:        https://sourceforge.net/projects/guvcview/files/source/guvcview-src-%{version}.tar.bz2
# PATCH-FIX-OPENSUSE guvcview-SUSE.patch -- use SUSE-specific paths
Patch0:         guvcview-SUSE.patch
# PATCH-FIX-OPENSUSE guvcview-qt5-nolibs_qt5names.patch -- use libraries from the GTK+ package
Patch1:         guvcview-qt5-nolibs_qt5names.patch
# PATCH-FIX-OPENSUSE 0001-Fix-build-with-GCC-14.patch -- Upstream already has the fix (although part of bigger changeset)
Patch2:         0001-Fix-build-with-GCC-14.patch
BuildRequires:  alsa-devel
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext
BuildRequires:  gsl-devel
BuildRequires:  gtk3-devel
BuildRequires:  intltool
BuildRequires:  libpng-devel
BuildRequires:  libpulse-devel
BuildRequires:  libtool
BuildRequires:  libusb-1_0-devel
BuildRequires:  libv4l-devel
BuildRequires:  pkgconfig
BuildRequires:  portaudio-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(sdl2)
%if %{with qt5}
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(libgviewaudio)
BuildRequires:  pkgconfig(libgviewencoder)
BuildRequires:  pkgconfig(libgviewrender)
BuildRequires:  pkgconfig(libgviewv4l2core)
%endif
Recommends:     %{name}-lang

%description
A GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package     -n libgviewaudio-%{sover0}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries

%description -n libgviewaudio-%{sover0}
A GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package     -n libgviewencoder-%{sover1}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries

%description -n libgviewencoder-%{sover1}
A GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package     -n libgviewrender-%{sover1}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries

%description -n libgviewrender-%{sover1}
A GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package     -n libgviewv4l2core-%{sover1}
Summary:        GTK+ UVC Viewer and Capturer
Group:          System/Libraries
Recommends:     libgviewv4l2core-lang

%description -n libgviewv4l2core-%{sover1}
A GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

%package        devel
Summary:        Development files for guvcview
Group:          Development/Libraries/C and C++
Requires:       alsa-devel
Requires:       glibc-devel
Requires:       gsl-devel
Requires:       libSDL2-devel
Requires:       libgviewaudio-%{sover0} = %{version}-%{release}
Requires:       libgviewencoder-%{sover1} = %{version}-%{release}
Requires:       libgviewrender-%{sover1} = %{version}-%{release}
Requires:       libgviewv4l2core-%{sover1} = %{version}-%{release}
Requires:       libpng-devel
Requires:       libpulse-devel
Requires:       libudev-devel
Requires:       libusb-1_0-devel
Requires:       libv4l-devel
Requires:       portaudio-devel
Requires:       pkgconfig(libavcodec)
Requires:       pkgconfig(libavutil)

%description devel
A GTK interface for capturing and viewing video from devices
supported by the Linux UVC driver, although it should also work with
any v4l2 compatible device.

This subpackage contains the header files for developing
applications that want to make use of the GUVC libraries.

%lang_package

%package     -n libgviewv4l2core-lang
Summary:        Languages for libgviewv4l2core
Group:          System/Localization
Requires:       libgviewv4l2core-%{sover1} = %{version}
Provides:       libgviewv4l2core-lang-all = %{version}
Supplements:    (bundle-lang-other and libgviewv4l2core-%{sover1})
BuildArch:      noarch

%description -n libgviewv4l2core-lang
Provides translations to libgviewv4l2core.

%prep
%setup -q -n %{pname}-src-%{version}
%patch -P 0 -p1
%patch -P 2 -p1
%if %{with qt5}
%patch -P 1 -p1
%endif

%build
# autoconf is too old in Leap
%if 0%{?suse_version} == 1500
sed -i '/AC_CHECK_INCLUDES_DEFAULT/d' configure.ac
%endif

autoreconf -fiv
%configure --disable-debian-menu \
           --disable-desktop \
%if %{with qt5}
           --disable-gtk3 \
           --enable-qt5 \
           --program-suffix=-qt5 \
%endif
%{nil}
%make_build

%install
%make_install
# Create desktop file as disabled during build
%suse_update_desktop_file -c %{name} "A video viewer and capturer for the linux uvc driver" %{name} %{name} %{name} AudioVideo AudioVideoEditing
%find_lang %{name} %{?no_lang_C}

%if %{with qt5}
mv %{buildroot}%{_datadir}/pixmaps/%{pname}.png %{buildroot}%{_datadir}/pixmaps/%{name}.png
%else
%find_lang gview_v4l2core libgviewv4l2core.lang %{?no_lang_C}
%endif

%fdupes %{buildroot}

%if ! %{with qt5}
rm %{buildroot}%{_libdir}/*.{la,a}

%ldconfig_scriptlets -n libgviewaudio-%{sover0}
%ldconfig_scriptlets -n libgviewencoder-%{sover1}
%ldconfig_scriptlets -n libgviewrender-%{sover1}
%ldconfig_scriptlets -n libgviewv4l2core-%{sover1}
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog README.md
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.png
%{_mandir}/man1/%{name}.1%{?ext_man}

%if ! %{with qt5}
%files -n libgviewaudio-%{sover0}
%{_libdir}/libgviewaudio-*.so.*

%files -n libgviewencoder-%{sover1}
%{_libdir}/libgviewencoder-*.so.*

%files -n libgviewrender-%{sover1}
%{_libdir}/libgviewrender-*.so.*

%files -n libgviewv4l2core-%{sover1}
%{_libdir}/libgviewv4l2core-*.so.*

%files devel
%dir %{_includedir}/guvcview-2
%dir %{_includedir}/guvcview-2/libgviewaudio
%dir %{_includedir}/guvcview-2/libgviewencoder
%dir %{_includedir}/guvcview-2/libgviewrender
%dir %{_includedir}/guvcview-2/libgviewv4l2core
%{_includedir}/guvcview-2/libgviewaudio/gviewaudio.h
%{_includedir}/guvcview-2/libgviewencoder/gviewencoder.h
%{_includedir}/guvcview-2/libgviewrender/gviewrender.h
%{_includedir}/guvcview-2/libgviewv4l2core/gview.h
%{_includedir}/guvcview-2/libgviewv4l2core/gviewv4l2core.h
%{_libdir}/libgviewaudio.so
%{_libdir}/libgviewencoder.so
%{_libdir}/libgviewrender.so
%{_libdir}/libgviewv4l2core.so
%{_libdir}/pkgconfig/libgviewaudio.pc
%{_libdir}/pkgconfig/libgviewencoder.pc
%{_libdir}/pkgconfig/libgviewrender.pc
%{_libdir}/pkgconfig/libgviewv4l2core.pc

%files -n libgviewv4l2core-lang -f libgviewv4l2core.lang
%endif

%files lang -f %{name}.lang

%changelog
* Tue Aug 27 2024 Dave Plater <davejplater@gmail.com>
- Revert to ffmpeg-7
* Tue Aug 27 2024 Dave Plater <davejplater@gmail.com>
- Force ffmpeg-6 library use in order to fix build
* Tue Aug 27 2024 Christophe Marin <christophe@krop.fr>
- Update to 2.1.0
  * Fix audio channels deprecated warning for avcodec >= 58
  * Add button click support for certain type of digital
    microscopes
  * Small fixes
  * Fix minimum version for audio channels api deprecated
    warning for avcodec >= 59
  * Fix COPYING to the same GPL version (v2) as the source files
  * Add binary fx filter
  * Make guvcview skip metadada devices
  * Enable OSD crosshair size to be changed in config
- Add patch to fix build failure with GCC 14:
  * 0001-Fix-build-with-GCC-14.patch
- Fix license. There's no GPL-3.0-only file that could impact
  the binaries license.
- Spec cleanup
* Tue Feb 27 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Aug  8 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.8:
  * Fix libav API break (ticket #70)
  * Update autoconf scripts
  * Support for building against ffmpeg5.
- Changes from version 2.0.7:
  * Fix audio encoder (tickets #64 and #65)
  * Use current theme icons (get icon by name)
- Convert to multibuild with qt5 as additional flavor:
  * Drop guvcview-qt5.spec, guvcview-qt5.changes, pre_checkin.sh
    script.
  * Drop hunks from guvcview-qt5-nolibs_qt5names.patch duplicated
    in guvcview-SUSE.patch.
  * Adapt BuildRequires for the additional flavour appropriately.
- Update so versions in keeping with upstream shlib versioning.
- Replace packageand type Supplements with RPM binary Supplements.
- Update guvcview-SUSE.patch to drop icon dir restructuring: no
  longer needed after all theme-able application icons dropped.
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to shortcut through the -mini flavors.
* Tue Feb 12 2019 bjorn.lie@gmail.com
- Update to version 2.0.6:
  * No upstream changes provided, please see
    https://sourceforge.net/p/guvcview/git-master/ci/master/tree/
- No longer force use ffmpeg3 version of pkgconfig(libav*).
- Drop guvcview-qt5-ppc64_QVariant.patch: Fixed upstream.
- Rebase guvcview-qt5-nolibs_qt5names.patch with quilt.
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Mon Sep 11 2017 jengelh@inai.de
- Update summary of -devel subpackage.
* Sat Jul 29 2017 aloisio@gmx.com
- Update to version 2.0.5
  * terminate configure if qt5 is enabled and moc is missing
  * add sfml render
  * fix aac encoder (replace experimental aac by libvo_aacenc)
  * fix build against newer kernels
  * disable window key pressed events if a string control has focus
  * fix video monotonic pts flag value in encoder context
  * fix audio cleanup
  * add support for HEVC (h265) video codec
  * fix muxed h264 support; fix raw output (alloc outbuf frame)
  * add circular buffer for delayed audio frames pts
  * remove support for older libavcodec versions (< 54.01)
  * add support for VP9
  * fix motion estimation method for x264 [1-4]
  * fix buggy behaviour for file names without extension
  * add support for sfml render
  * drop support for sdl1 based render
  * Flavio Spagnuolo <flavio.spagnuolo@gmail.com>: fix matroska
    clean up when audio is disabled
  * fix segfault when destroying mutexes by unlocking already
    unlocked mutexes
  * fix libc readdir_r deprecated warning: replace by readdir
  * add extra video fx filters
- Dropped guvcview-2.0.4_ffmpeg-3.0.patch (merged upstream)
- Split lang package contents between guvcview-lang and a new
  libgviewv4l2core-lang
- Added separate -qt5 and -qt5-lang packages and pre_checkin.sh
  and guvcview-qt5-nolibs_qt5names.patch to support them
- Added guvcview-qt5-ppc64_QVariant.patch to fix build on ppc64
- Replaced some in-spec commands with guvcview-SUSE.patch
* Thu Mar  2 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use
- Ensure description neutrality
* Sun May  1 2016 aloisio@gmx.com
- Update to version 2.0.4:
  * drop support for internal 422 packed format (use only 420 planar)
  * add support for extra pixel formats, including be formats
  * add command line option for requesting fps
  * add support for control events
  * add support for string, int64, bitmask and integer menu controls
  * make sure we can't select unsuported pix formats from the gui
  * fix status message for QT5 interface
  * move mutexes to device handlers (context)
  * v4l2core and audio api - don't access device data directly (use opaque structures)
  * add constructor and destructor functions for v4l2core and encoder
    Paulo Assis <pj.assis@gmail.com> Mon, 22 Feb 2016 10:10:00 +0100
  2.0.3:
  * Add Qt5 interface (--enable-qt5)
  * fix '-n' option (don't save frame when photo countdown reaches 0)
  * restore exit_on_term option
  * use AC_SYS_LARGEFILE m4 macro for enabling Large File Support (LFS) on 32 bit systems
  * add color config for crosshair osd
  * change rendering engine to use updateTexture instead of lock/unlock texture
  * change rendering lib to avoid frame copy when using osd
    Paulo Assis <pj.assis@gmail.com> Mon, 4 Jan 2016 23:34:00 +0100
- Dropped guvcview-implicit-pointer-decl.patch
  guvcview-no-return-in-nonvoid-function.patch
  guvcview-voidreturn.patch
- Added guvcview-2.0.4_ffmpeg-3.0.patch
* Tue Sep 22 2015 olaf@aepfle.de
- Use pkgconfig for ffmpeg BuildRequires
* Wed Aug  5 2015 joerg.lorenzen@ki.tng.de
- Update to version 2.0.2:
  + fix mjpeg and h264 decoders (libav): init avpacket.
  + fix wrong logic of enable switches (Marvin Schmidt  ticket #12).
  + create a frame queue and refactor frame grab/decode.
  + fix jpeg decoder for older libavcodec api ( < 54.25).
  + attach video capture to SIGUSR1 signal.
  + add audio latency control to gui.
  + change default portaudio latency to high latency.
  + set device during initialization.
  + use time for matroska segment uid if gsl is disabled.
  + fix array index causing buffer overflow.
  + restore CPPFLAGS after AC_CHECK_HEADERS.
  + remove direct access to device data in v4l2core lib.
  + make sure to stop encoder thread before exiting capture thread.
  + avoid SIGFPE on bad channels or samprate data inside audio
    capture callbacks.
  + remove check for avcodec.h (it's needed for very old libavcodec
    versions); set iyuv as default internal format (over yuyv).
  + add basic support for continuous and stepwise frame sizes.
  + add support for empty control list.
  + add code for crossair osd.
  + fix h264 demux from mjpg container.
  + fix pan/tilt for logitech peripheral V3 (use raw control
    instead of v4l2).
* Fri Oct 31 2014 joerg.lorenzen@ki.tng.de
- Update to version 2.0.1:
  + Fix audio clean bug (segfault when audio=none).
  + Add --disable_libv4l2 option.
  + Add support for internal yu12 planar format.
  + Workaround uvcvideo bug (buf.bytesused=0 on kernels >=3.16).
- Changes since version 2.0.0:
  + New version 2.0.0 (code rewriten from scratch).
  + Move all core functions to 4 shared libs.
  + Change options.
  + Change config.
  + Add sdl2 render.
  + Use gsl for random number generation.
- Changes since version 1.7.3:
  + Add silence frames to compensate audio drift (delay).
  + Fix possible memory leak.
  + Add video and image capture through system signals:
    SIGUSR1 and SIGUSR2.
  + Add true no_display mode (no X required).
  + Small bug fixes.
- Changes since version 1.7.2:
  + Add H264 decoding support.
  + Sync translations.
- Changes since version 1.7.1:
  + Fix avi muxer: fix opendml indexes (>= 1Gb).
  + Update Italian translation.
* Tue Jul 30 2013 i@margueirte.su
- build against libffmpeg-devel.
* Sat Jul 20 2013 zaitor@opensuse.org
- Update to version 1.7.0:
  + Refactor avi muxer (base it on libav muxer with opendml
    support).
  + Refactor mkv muxer (base it on libav muxer with webm support).
  + Add VP8, Theora and Vorbis codecs.
  + Add Webm support.
  + Add a Top Menu.
  + Move all file operations to the Top Menu.
* Thu Sep 20 2012 zaitor@opensuse.org
- Update to version 1.6.1:
  + Fix build with latest libavcodec.
  + Fix audio codecs listing.
  + Fix audio codecs (AC3 and AAC) input format for latest
    libavcodec API (float).
  + Add support for delayed frames in video encoding.
- Changes since version 1.6.0:
  + Run audio in separate thread.
  + Update audio buffer.
  + Move pulse audio interface from simple to async API.
  + Add pulse device list.
  + Enable build of pulse API by default.
- Added new build dependency, intltool.
* Sun May 20 2012 zaitor@opensuse.org
- Update to version 1.5.3:
  + Update libavcodec API.
  + Add libavutil dependency.
  + Fix pulse interface.
  + Update language catalogs.
- Drop guvcview-pulseaudio-fix.patch, fixed upstream.
- Change BuildRequires: pulseaudio-devel to libpulse-devel.
* Sun Feb 26 2012 zaitor@opensuse.org
- Update to version 1.5.2:
  + Move to pthreads (fix gthread API 2 issues).
  + Add italian translation.
  + Fix several libavcodec issues.
  + Fix some gtk3 widgets.
- Drop guvcview-fix-glib-include.patch, fixed upstream.
- Add guvcview-pulseaudio-fix.patch: Fix pulseaudio interface.
* Mon Jan 23 2012 malcolmlewis@opensuse.org
- Updated to version 1.5.1:
  + Moved to gtk3.
  + Make control window size dependent on screen resolution.
  + Threaded coding patch - George Sedov <radist.morse@gmail.com>.
  + Fix h264 codec properties.
- Updates from version 1.5.0:
  + Add a no display mode (--no_display).
  + Fix build issues with newer versions (>=0.7.x) of ffmpeg
    libavcodec.
  + Add support for unix signals.
  + Add VU meter OSD.
  + Fix menu controls (linux 3.0).
- Add guvcview-fix-glib-include.patch: To fix only <glib.h> can be
  included directly error for builds > 1210.
* Mon Oct  3 2011 malcolmlewis@opensuse.org
- Fix guvcview.desktop file in spec file.
* Fri Jul  1 2011 malcolmlewis@opensuse.org
- Initial build based on fc15 spec file.
